@@ -1173,7 +1173,7 @@ public class AnalyzerTest extends AsmTest {
   private static class MockInterpreter extends Interpreter<MockValue> {
 
     MockInterpreter() {
-      super(Opcodes.ASM7);
+      super(/* latest */ Opcodes.ASM8_EXPERIMENTAL);
     }
 
     @Override
