@@ -27,14 +27,21 @@
 // THE POSSIBILITY OF SUCH DAMAGE.
 package org.objectweb.asm;
 
+import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.io.ByteArrayInputStream;
+import java.io.InputStream;
 import java.lang.reflect.Field;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Set;
 import java.util.stream.Collectors;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.function.Executable;
 
 /**
  * Unit tests for {@link Constants}.
@@ -137,8 +144,7 @@ public class ConstantsTest {
     List<Field> verificationTypeInfoTags = getConstants(ConstantType.VERIFICATION_TYPE_INFO_TAG);
 
     Set<Integer> verificationTypeInfoTagValues =
-        verificationTypeInfoTags
-            .stream()
+        verificationTypeInfoTags.stream()
             .map(ConstantsTest::getIntegerValue)
             .collect(Collectors.toSet());
 
@@ -162,9 +168,54 @@ public class ConstantsTest {
     }
   }
 
+  @Test
+  public void testIsWhitelisted() {
+    assertFalse(Constants.isWhitelisted("org/jacoco/core/internal/flow/ClassProbesVisitor"));
+    assertFalse(Constants.isWhitelisted("org/objectweb/asm/ClassWriter"));
+    assertFalse(Constants.isWhitelisted("org/objectweb/asm/util/CheckClassVisitor"));
+    assertFalse(Constants.isWhitelisted("org/objectweb/asm/ClassWriterTest"));
+    assertTrue(Constants.isWhitelisted("org/objectweb/asm/ClassWriterTest$DeadCodeInserter"));
+    assertTrue(Constants.isWhitelisted("org/objectweb/asm/util/TraceClassVisitor"));
+    assertTrue(Constants.isWhitelisted("org/objectweb/asm/util/CheckClassAdapter"));
+  }
+
+  @Test
+  public void testCheckIsPreview_nullStream() {
+    Executable checkIsPreview = () -> Constants.checkIsPreview(null);
+
+    assertThrows(IllegalStateException.class, checkIsPreview);
+  }
+
+  @Test
+  public void testCheckIsPreview_invalidStream() {
+    InputStream invalidStream = new ByteArrayInputStream(new byte[4]);
+
+    Executable checkIsPreview = () -> Constants.checkIsPreview(invalidStream);
+
+    assertThrows(IllegalStateException.class, checkIsPreview);
+  }
+
+  @Test
+  public void testCheckIsPreview_nonPreviewClass() {
+    InputStream nonPreviewStream = new ByteArrayInputStream(new byte[8]);
+
+    Executable checkIsPreview = () -> Constants.checkIsPreview(nonPreviewStream);
+
+    assertThrows(IllegalStateException.class, checkIsPreview);
+  }
+
+  @Test
+  public void testCheckIsPreview_previewClass() {
+    byte[] previewClass = new byte[] {0, 0, 0, 0, (byte) 0xFF, (byte) 0xFF};
+    InputStream previewStream = new ByteArrayInputStream(previewClass);
+
+    Executable checkIsPreview = () -> Constants.checkIsPreview(previewStream);
+
+    assertDoesNotThrow(checkIsPreview);
+  }
+
   private static List<Field> getConstants(final ConstantType constantType) {
-    return Arrays.asList(Constants.class.getFields())
-        .stream()
+    return Arrays.asList(Constants.class.getFields()).stream()
         .filter(field -> getType(field).equals(constantType))
         .collect(Collectors.toList());
   }
@@ -175,6 +226,7 @@ public class ConstantsTest {
       case "ASM5":
       case "ASM6":
       case "ASM7":
+      case "ASM8_EXPERIMENTAL":
         return ConstantType.ASM_VERSION;
       case "V_PREVIEW":
       case "V1_1":
@@ -191,6 +243,7 @@ public class ConstantsTest {
       case "V12":
       case "V13":
       case "V14":
+      case "V15":
         return ConstantType.CLASS_VERSION;
       case "ACC_PUBLIC":
       case "ACC_PRIVATE":
@@ -217,6 +270,7 @@ public class ConstantsTest {
       case "ACC_MODULE":
         return ConstantType.ACCESS_FLAG;
       case "ACC_DEPRECATED":
+      case "ACC_SEALED":
       case "ACC_CONSTRUCTOR":
         return ConstantType.ASM_ACCESS_FLAG;
       case "T_BOOLEAN":
